%define debug_package %{nil}

%define version_major 5.0
%define version_minor 9.2
%define version_main %{version}
%define version_lite %{version}
%define ipv6_ver %{version}
%define ipv6_lite_ver %{version}
%define sha1sums_ver %{version}
%define ftp_ver %{version_major}.9
%define ftp_path ftp://ftp.shorewall.net/pub/shorewall/%{version_major}/%{name}-%{ftp_ver}

%define name6 %{name}6

Summary:	Iptables-based firewall for Linux systems
Name:		shorewall
Version:	%{version_major}.%{version_minor}
Release:	%mkrel 1
License:	GPLv2+ and LGPLv2.1+
Group:		System/Servers
URL:		http://www.shorewall.net/
Source0:	%{ftp_path}/%{name}-%{version}.tar.bz2
Source1:	%{ftp_path}/%{name}-lite-%{version_lite}.tar.bz2
Source2:	%{ftp_path}/%{name}-docs-html-%{version}.tar.bz2
Source3:	%{ftp_path}/%{name6}-%{ipv6_ver}.tar.bz2
Source4:	%{ftp_path}/%{name6}-lite-%{ipv6_lite_ver}.tar.bz2
Source5:	%{ftp_path}/%{sha1sums_ver}.sha1sums
Source6:	%{ftp_path}/%{name}-core-%{version}.tar.bz2
Patch4:		%{name}-4.4.23-allow-netmask-0.patch
Patch6:		shorewall-4.6.13.1-mga_fix.patch
Requires:	iptables
Requires:	iproute2
Requires:	shorewall-core = %{version}-%{release}
Requires(post):	rpm-helper
Requires(preun): rpm-helper
BuildArch:	noarch

%description
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

%package core
Summary:	Shorewall core libraries
Group:		System/Servers
Conflicts:	shorewall < 4.5
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description core
An IPv6 enabled and capable Shoreline Firewall.


%package ipv6
Summary:	IPv6 capable Shorewall
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	iptables-ipv6
Requires:	iproute2
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description ipv6
An IPv6 enabled and capable Shoreline Firewall.

%package ipv6-lite
Summary:	Lite version of ipv6 shorewall
Group:		System/Servers
Requires:	%{name}-ipv6 = %{version}-%{release}
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description ipv6-lite
Shorewall IPv6 Lite is a companion product to Shorewall IPv6 that allows 
network administrators to centralize the configuration of Shorewall-based
firewalls.

%package lite
Summary:	Lite version of shorewall
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description lite
Shorewall Lite is a companion product to Shorewall that allows network
administrators to centralize the configuration of Shorewall-based firewalls.

%package doc
Summary:	Firewall scripts
Group:		Documentation
BuildArch:  noarch

%description doc 
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

This package contains the docs.

%prep
%setup -q -c -n %{name}-%{version}
%setup -q -T -D -a 1
%setup -q -T -D -a 2
%setup -q -T -D -a 3
%setup -q -T -D -a 4
%setup -q -T -D -a 6

pushd %{name}-%{version_main}
%patch4 -p1 -b .allow-netmask-0
popd

# use one patch for all (easiest fix)
for i in shorewall-%{version} shorewall6-%{version} \
    shorewall6-lite-%{version} shorewall-core-%{version} \
    shorewall-lite-%{version}; do
pushd $i
%patch6 -p1
popd
done

# another fixup
for i in shorewall-%{version} shorewall6-%{version} \
    shorewall6-lite-%{version}  shorewall-lite-%{version}; do
pushd $i
cp default.debian sysconfig
popd
done

%build
# (tpg) we do nothing here

%install
rm -rf %buildroot
mkdir -p %{buildroot}

export PREFIX=%{buildroot}
export OWNER=`id -n -u`
export GROUP=`id -n -g`

export CONFDIR=%{_sysconfdir}/%{name}

pushd %{name}-core-%{version_main}
./configure.pl INITFILE= SYSTEMD= SBINDIR=/sbin LIBEXEC=/usr/libexec
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

pushd %{name}-%{version_main}
# (blino) enable startup (new setting as of 2.1.3)
perl -pi -e 's/STARTUP_ENABLED=.*/STARTUP_ENABLED=Yes/' configfiles/%{name}.conf

# Keep synced with net.ipv4.ip_forward var in /etc/sysctl.conf
perl -pi -e 's/IP_FORWARDING=.*/IP_FORWARDING=Keep/' configfiles/%{name}.conf

# blank Internal option	 
perl -pi -e 's/TC_ENABLED=Internal/TC_ENABLED=/' configfiles/%{name}.conf

# (tpg) do the optimizations
perl -pi -e 's/OPTIMIZE=.*/OPTIMIZE=1/' configfiles/%{name}.conf

# (tpg) set config path
perl -pi -e 's#CONFIG_PATH=.*#CONFIG_PATH=configfiles/%{/g_sysconfdir}/%{name}#' configpath

# (lmenut) kernel modules are compressed by default
perl -pi -e 's#MODULE_SUFFIX=.*#MODULE_SUFFIX="ko ko.xz ko.gz"#' configfiles/%{name}.conf

# (alien) have accounting by default in the mangle table
perl -pi -e 's#ACCOUNTING_TABLE=.*#ACCOUNTING_TABLE=mangle#' configfiles/%{name}.conf

./configure.pl INITFILE= SYSTEMD= SBINDIR=/sbin LIBEXEC=/usr/libexec

# let's do the install
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

#(tpg) IPv6
pushd %{name6}-%{ipv6_ver}
# (blino) enable startup (new setting as of 2.1.3)
perl -pi -e 's/STARTUP_ENABLED=.*/STARTUP_ENABLED=Yes/' configfiles/%{name6}.conf
# Keep synced with net.ipv4.ip_forward var in /etc/sysctl.conf
perl -pi -e 's/IP_FORWARDING=.*/IP_FORWARDING=Keep/' configfiles/%{name6}.conf
# (lmenut) kernel modules are compressed by default)
perl -pi -e 's#MODULE_SUFFIX=.*#MODULE_SUFFIX="ko ko.xz ko.gz"#' configfiles/%{name6}.conf
./configure.pl INITFILE= SYSTEMD= SBINDIR=/sbin LIBEXEC=/usr/libexec
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

pushd %{name6}-lite-%{ipv6_lite_ver}
./configure.pl INITFILE= SYSTEMD= SBINDIR=/sbin LIBEXEC=/usr/libexec
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

pushd %{name}-lite-%{version_lite}
./configure.pl INITFILE= SYSTEMD= SBINDIR=/sbin LIBEXEC=/usr/libexec
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

# Suppress automatic replacement of "echo" by "gprintf" in the shorewall
# startup script by RPM. This automatic replacement is broken.
export DONT_GPRINTIFY=1

#(tpg) looks like these files are needed
touch %{buildroot}/%{_var}/lib/shorewall/{chains,nat,proxyarp,restarted,zones,restore-base,restore-tail,state,.modules,.modulesdir,.iptables-restore-input,.start,.restart,.restore}
touch %{buildroot}/%{_var}/lib/shorewall-lite/firewall

#(tpg) ipv6
touch %{buildroot}/%{_var}/lib/%{name6}/{chains,restarted,zones,restore-base,restore-tail,state,.modules,.modulesdir,.iptables-restore-input,.start,.restart,.restore}
touch %{buildroot}/%{_var}/lib/%{name6}-lite/firewall

#remove unused files because of %exclude misbehaviour
rm -f %{buildroot}%{_datadir}/%{name6}/configfiles/*
rm -f %{buildroot}%{_datadir}/shorewall/configfiles/*

# Don't install systemd service in /lib/systemd
rm -f %{buildroot}/lib/systemd/system/shorewall.service
rm -f %{buildroot}/lib/systemd/system/shorewall-lite.service
rm -f %{buildroot}/lib/systemd/system/shorewall6.service
rm -f %{buildroot}/lib/systemd/system/shorewall6-lite.service

# (tmb) allow outgoing traffic on any interface by default (mga#10947)
# (cg) drop the ?FORMAT 2 line as it disagrees with 'detect' (mga#11928)
perl -n -i -e 'print unless m!^?FORMAT 2$!' %{buildroot}%{_sysconfdir}/%{name}/interfaces
echo "net	+	detect" >> %{buildroot}%{_sysconfdir}/%{name}/interfaces
perl -n -i -e 'print unless m!^?FORMAT 2$!' %{buildroot}%{_sysconfdir}/%{name6}/interfaces
echo "net	+	detect" >> %{buildroot}%{_sysconfdir}/%{name6}/interfaces

%post
if [ "$1" -gt 1 ] ; then
  perl -pi -e 's#MODULE_SUFFIX=ko$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name}/%{name}.conf
  perl -pi -e 's#MODULE_SUFFIX=\"ko ko.gz\"$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name}/%{name}.conf
fi
%_post_service shorewall

%create_ghostfile %{_var}/lib/%{name}/chains root root 644
%create_ghostfile %{_var}/lib/%{name}/nat root root 644
%create_ghostfile %{_var}/lib/%{name}/proxyarp root root 644
%create_ghostfile %{_var}/lib/%{name}/restarted root root 644
%create_ghostfile %{_var}/lib/%{name}/zones root root 644
%create_ghostfile %{_var}/lib/%{name}/restore-base root root 644
%create_ghostfile %{_var}/lib/%{name}/restore-tail root root 644
%create_ghostfile %{_var}/lib/%{name}/state root root 644
%create_ghostfile %{_var}/lib/%{name}/.modules root root 644
%create_ghostfile %{_var}/lib/%{name}/.modulesdir root root 644
%create_ghostfile %{_var}/lib/%{name}/.iptables-restore-input root root 644
%create_ghostfile %{_var}/lib/%{name}/.restart root root 700
%create_ghostfile %{_var}/lib/%{name}/.restore root root 700
%create_ghostfile %{_var}/lib/%{name}/.start root root 700

%preun
%_preun_service %{name}
if [ $1 = 0 ] ; then
  rm -f %{_sysconfdir}/%{name}/startup_disabled
  rm -f %{_var}/lib/%{name}/*
fi

%post lite
%_post_service %{name}-lite
%create_ghostfile %{_var}/lib/%{name}-lite/firewall root root 644

%preun lite
%_preun_service %{name}-lite

%post ipv6
if [ "$1" -gt 1 ] ; then
  perl -pi -e 's#MODULE_SUFFIX=ko$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name6}/%{name6}.conf
  perl -pi -e 's#MODULE_SUFFIX=\"ko ko.gz\"$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name6}/%{name6}.conf
fi
%_post_service %{name6}

%create_ghostfile %{_var}/lib/%{name6}/chains root root 644
%create_ghostfile %{_var}/lib/%{name6}/restarted root root 644
%create_ghostfile %{_var}/lib/%{name6}/zones root root 644
%create_ghostfile %{_var}/lib/%{name6}/restore-base root root 644
%create_ghostfile %{_var}/lib/%{name6}/restore-tail root root 644
%create_ghostfile %{_var}/lib/%{name6}/state root root 644
%create_ghostfile %{_var}/lib/%{name6}/.modules root root 644
%create_ghostfile %{_var}/lib/%{name6}/.modulesdir root root 644
%create_ghostfile %{_var}/lib/%{name6}/.iptables-restore-input root root 644
%create_ghostfile %{_var}/lib/%{name6}/.restart root root 700
%create_ghostfile %{_var}/lib/%{name6}/.restore root root 700
%create_ghostfile %{_var}/lib/%{name6}/.start root root 700

%preun ipv6
%_preun_service %{name6}
if [ $1 = 0 ] ; then
  rm -f %{_sysconfdir}/%{name6}/startup_disabled
  rm -f %{_var}/lib/%{name6}/*
fi

%post ipv6-lite
%_post_service %{name6}-lite
%create_ghostfile %{_var}/lib/%{name6}-lite/firewall root root 644

%preun ipv6-lite
%_preun_service %{name6}-lite

%files
%doc %{name}-%{version_main}/{changelog.txt,releasenotes.txt,Samples}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_datadir}/%{name}
%dir %attr(755,root,root) %{_var}/lib/%{name}
%ghost %{_var}/lib/%{name}/*
%ghost %{_var}/lib/%{name}/.??*
%config %{_sysconfdir}/logrotate.d/%{name}
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}
%attr(755,root,root) /sbin/%{name}
%{_datadir}/%{name}/action*
%{_datadir}/%{name}/configpath
%dir %{_datadir}/%{name}/deprecated
%{_datadir}/%{name}/deprecated/action.A_Reject
%{_datadir}/%{name}/deprecated/macro.SNMPTrap
%{_datadir}/%{name}/helpers
%{_datadir}/%{name}/lib.cli-std
%{_datadir}/%{name}/lib.runtime
%{_datadir}/%{name}/macro.*
%{_datadir}/%{name}/modules*
%{_datadir}/%{name}/version
/usr/libexec/%{name}/getparams
/usr/libexec/%{name}/wait4ifup
%{_mandir}/man5/%{name}-accounting.5.*
%{_mandir}/man5/%{name}-actions.5.*
#%{_mandir}/man5/%{name}-blacklist.5.*
%{_mandir}/man5/%{name}-ecn.5.*
%{_mandir}/man5/%{name}-exclusion.5.*
%{_mandir}/man5/%{name}-hosts.5.*
%{_mandir}/man5/%{name}-interfaces.5.*
%{_mandir}/man5/%{name}-ipsets.5.*
%{_mandir}/man5/%{name}-maclist.5.*
%{_mandir}/man5/%{name}-mangle.5.*
%{_mandir}/man5/%{name}-masq.5.*
%{_mandir}/man5/%{name}-modules.5.*
%{_mandir}/man5/%{name}-nat.5.*
%{_mandir}/man5/%{name}-nesting.5.*
%{_mandir}/man5/%{name}-netmap.5.*
%{_mandir}/man5/%{name}-params.5.*
%{_mandir}/man5/%{name}-policy.5.*
%{_mandir}/man5/%{name}-providers.5.*
%{_mandir}/man5/%{name}-proxyarp.5.*
%{_mandir}/man5/%{name}-routes.5.*
#{_mandir}/man5/%{name}-routestopped.5.*
%{_mandir}/man5/%{name}-rules.5.*
%{_mandir}/man5/%{name}-secmarks.5.*
%{_mandir}/man5/%{name}-tcclasses.5.*
%{_mandir}/man5/%{name}-tcinterfaces.5.*
%{_mandir}/man5/%{name}-tcpri.5.*
%{_mandir}/man5/%{name}-tcdevices.5.*
%{_mandir}/man5/%{name}-tcfilters.5.*
#%{_mandir}/man5/%{name}-tcrules.5.*
#%{_mandir}/man5/%{name}-tos.5.*
%{_mandir}/man5/%{name}-tunnels.5.*
%{_mandir}/man5/%{name}-vardir.5.*
%{_mandir}/man5/%{name}-zones.5.*
%{_mandir}/man5/%{name}.conf.5.*
%{_mandir}/man8/%{name}.8.*
%{_mandir}/man8/%{name}-init.8.*
%{_mandir}/man5/%{name}-blrules.5.*
%{_mandir}/man5/%{name}-conntrack.5.*
%{_mandir}/man5/%{name}-rtrules.5.*
%{_mandir}/man5/%{name}-stoppedrules.5.*
%{_mandir}/man5/%{name}-arprules.5*
%{_datadir}/perl5/vendor_perl/Shorewall/*.pm
/usr/libexec/shorewall/compiler.pl
%{_datadir}/shorewall/prog.footer
/etc/rc.d/init.d/shorewall


%files ipv6
%doc %{name6}-%{ipv6_ver}/{changelog.txt,releasenotes.txt,tunnel,ipsecvpn,Samples6}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name6}
%dir %{_sysconfdir}/%{name6}
%dir %{_datadir}/%{name6}
%dir %attr(755,root,root) %{_var}/lib/%{name6}
%ghost %{_var}/lib/%{name6}/*
%ghost %{_var}/lib/%{name6}/.??*
%config(noreplace) %{_sysconfdir}/%{name6}/*
%config %{_sysconfdir}/logrotate.d/%{name6}
%attr(755,root,root) /sbin/%{name6}
%{_datadir}/%{name6}/action*
%{_datadir}/%{name6}/configpath
%{_datadir}/%{name6}/functions
%{_datadir}/%{name6}/helpers
%{_datadir}/%{name6}/lib.*
%{_datadir}/%{name6}/macro.*
%{_datadir}/%{name6}/modules*
%{_datadir}/%{name6}/version
%{_mandir}/man5/%{name6}-accounting.5.*
%{_mandir}/man5/%{name6}-actions.5.*
#%{_mandir}/man5/%{name6}-blacklist.5.*
%{_mandir}/man5/%{name6}-exclusion.5.*
%{_mandir}/man5/%{name6}-hosts.5.*
%{_mandir}/man5/%{name6}-interfaces.5.*
%{_mandir}/man5/%{name6}-ipsets.5.*
%{_mandir}/man5/%{name6}-maclist.5.*
%{_mandir}/man5/%{name6}-mangle.5.*
%{_mandir}/man5/%{name6}-modules.5.*
%{_mandir}/man5/%{name6}-nesting.5.*
%{_mandir}/man5/%{name6}-nat.5.*
%{_mandir}/man5/%{name6}-params.5.*
%{_mandir}/man5/%{name6}-policy.5.*
%{_mandir}/man5/%{name6}-providers.5.*
%{_mandir}/man5/%{name6}-proxyndp.5.*
%{_mandir}/man5/%{name6}-routes.5.*
#%{_mandir}/man5/%{name6}-routestopped.5.*
%{_mandir}/man5/%{name6}-rules.5.*
%{_mandir}/man5/%{name6}-secmarks.5.*
%{_mandir}/man5/%{name6}-tcclasses.5.*
%{_mandir}/man5/%{name6}-tcdevices.5.*
%{_mandir}/man5/%{name6}-tcfilters.5.*
%{_mandir}/man5/%{name6}-tcinterfaces.5.*
%{_mandir}/man5/%{name6}-tcpri.5.*
#%{_mandir}/man5/%{name6}-tcrules.5.*
#%{_mandir}/man5/%{name6}-tos.5.*
%{_mandir}/man5/%{name6}-tunnels.5.*
%{_mandir}/man5/%{name6}-vardir.5.*
%{_mandir}/man5/%{name6}-zones.5.*
%{_mandir}/man5/%{name6}.conf.5.*
%{_mandir}/man8/%{name6}.8.*
%{_mandir}/man5/%{name6}-blrules.5.*
%{_mandir}/man5/%{name6}-conntrack.5.*
%{_mandir}/man5/%{name6}-rtrules.5.*
%{_mandir}/man5/%{name6}-stoppedrules.5.*
%{_mandir}/man5/%{name6}-netmap.5.*
%{_mandir}/man5/%{name6}-masq.5*
/etc/rc.d/init.d/shorewall6

%files lite
%doc %{name}-lite-%{version_lite}/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}-lite
%dir %{_datadir}/%{name}-lite
%dir %attr(755,root,root) %{_var}/lib/%{name}-lite
%ghost %{_var}/lib/%{name}-lite/*
%config(noreplace) %{_sysconfdir}/%{name}-lite/*
%config %{_sysconfdir}/logrotate.d/%{name}-lite
%attr(755,root,root) /sbin/%{name}-lite
%{_datadir}/%{name}-lite/configpath
%{_datadir}/%{name}-lite/functions
%{_datadir}/%{name}-lite/helpers
%{_datadir}/%{name}-lite/lib.*
%{_datadir}/%{name}-lite/modules*
%{_datadir}/%{name}-lite/version
%{_mandir}/man5/%{name}-lite*
%{_mandir}/man8/%{name}-lite*
/usr/libexec/%{name}-lite/shorecap
/etc/rc.d/init.d/shorewall-lite

%files ipv6-lite
%doc %{name6}-lite-%{ipv6_lite_ver}/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name6}-lite
%dir %{_datadir}/%{name6}-lite
%dir %attr(755,root,root) %{_var}/lib/%{name6}-lite
%ghost %{_var}/lib/%{name6}-lite/*
%config(noreplace) %{_sysconfdir}/%{name6}-lite/*
%config %{_sysconfdir}/logrotate.d/%{name6}-lite
%attr(755,root,root) /sbin/%{name6}-lite
%{_datadir}/%{name6}-lite/configpath
%{_datadir}/%{name6}-lite/functions
%{_datadir}/%{name6}-lite/helpers
%{_datadir}/%{name6}-lite/lib.*
%{_datadir}/%{name6}-lite/modules*
%{_datadir}/%{name6}-lite/version
%{_mandir}/man5/%{name6}-lite*
%{_mandir}/man8/%{name6}-lite*
/usr/libexec/%{name6}-lite/shorecap
/etc/rc.d/init.d/shorewall6-lite

%files doc
%doc %{name}-docs-html-%{version}/*

%files core
%doc shorewall-core-%{version}/{COPYING,changelog.txt,releasenotes.txt}
%dir %{_datadir}/shorewall/
%{_datadir}/shorewall/coreversion
%{_datadir}/shorewall/functions
%{_datadir}/shorewall/lib.base
%{_datadir}/shorewall/lib.cli
%{_datadir}/shorewall/lib.common
%{_datadir}/shorewall/shorewallrc


%changelog
* Mon Nov 21 2016 adrianomorselli <adrianomorselli> 5.0.9.2-1uplos2016
- rebuild

* Thu Jun 23 2016 bb <bb> 5.0.9.2-1pclos2016
- update

* Sat Apr 09 2016 bb <bb> 4.6.13.-1pclos2016
- update from france without systemd

